pub struct CreateServerOptions {Show 20 fields
pub node_uuid: Uuid,
pub owner_uuid: Uuid,
pub egg_uuid: Uuid,
pub backup_configuration_uuid: Option<Uuid>,
pub allocation_uuid: Option<Uuid>,
pub allocation_uuids: Vec<Uuid>,
pub start_on_completion: bool,
pub skip_installer: bool,
pub external_id: Option<CompactString>,
pub name: CompactString,
pub description: Option<CompactString>,
pub limits: AdminApiServerLimits,
pub pinned_cpus: Vec<i16>,
pub startup: CompactString,
pub image: CompactString,
pub timezone: Option<Tz>,
pub hugepages_passthrough_enabled: bool,
pub kvm_passthrough_enabled: bool,
pub feature_limits: ApiServerFeatureLimits,
pub variables: HashMap<Uuid, CompactString>,
}Fields
node_uuid: Uuidowner_uuid: Uuidegg_uuid: Uuidbackup_configuration_uuid: Option<Uuid>allocation_uuid: Option<Uuid>allocation_uuids: Vec<Uuid>start_on_completion: boolskip_installer: boolexternal_id: Option<CompactString>name: CompactStringdescription: Option<CompactString>limits: AdminApiServerLimitspinned_cpus: Vec<i16>startup: CompactStringimage: CompactStringtimezone: Option<Tz>hugepages_passthrough_enabled: boolkvm_passthrough_enabled: boolfeature_limits: ApiServerFeatureLimitsvariables: HashMap<Uuid, CompactString>Trait Implementations
Sourceimpl ComposeSchema for CreateServerOptions
impl ComposeSchema for CreateServerOptions
Sourceimpl<'de> Deserialize<'de> for CreateServerOptions
impl<'de> Deserialize<'de> for CreateServerOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl ToSchema for CreateServerOptions
impl ToSchema for CreateServerOptions
Sourceimpl Validate for CreateServerOptions
impl Validate for CreateServerOptions
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read morefn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
fn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read moreAuto Trait Implementations
impl Freeze for CreateServerOptions
impl RefUnwindSafe for CreateServerOptions
impl Send for CreateServerOptions
impl Sync for CreateServerOptions
impl Unpin for CreateServerOptions
impl UnwindSafe for CreateServerOptions