pub struct UpdateServerOptions {Show 15 fields
pub owner_uuid: Option<Uuid>,
pub egg_uuid: Option<Uuid>,
pub backup_configuration_uuid: Option<Option<Uuid>>,
pub suspended: Option<bool>,
pub external_id: Option<Option<CompactString>>,
pub name: Option<CompactString>,
pub description: Option<Option<CompactString>>,
pub limits: Option<AdminApiServerLimits>,
pub pinned_cpus: Option<Vec<i16>>,
pub startup: Option<CompactString>,
pub image: Option<CompactString>,
pub timezone: Option<Option<Tz>>,
pub hugepages_passthrough_enabled: Option<bool>,
pub kvm_passthrough_enabled: Option<bool>,
pub feature_limits: Option<ApiServerFeatureLimits>,
}Fields
owner_uuid: Option<Uuid>egg_uuid: Option<Uuid>backup_configuration_uuid: Option<Option<Uuid>>suspended: Option<bool>external_id: Option<Option<CompactString>>name: Option<CompactString>description: Option<Option<CompactString>>limits: Option<AdminApiServerLimits>pinned_cpus: Option<Vec<i16>>startup: Option<CompactString>image: Option<CompactString>timezone: Option<Option<Tz>>hugepages_passthrough_enabled: Option<bool>kvm_passthrough_enabled: Option<bool>feature_limits: Option<ApiServerFeatureLimits>Trait Implementations
Sourceimpl Clone for UpdateServerOptions
impl Clone for UpdateServerOptions
Sourcefn clone(&self) -> UpdateServerOptions
fn clone(&self) -> UpdateServerOptions
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for UpdateServerOptions
impl ComposeSchema for UpdateServerOptions
Sourceimpl Default for UpdateServerOptions
impl Default for UpdateServerOptions
Sourcefn default() -> UpdateServerOptions
fn default() -> UpdateServerOptions
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for UpdateServerOptions
impl<'de> Deserialize<'de> for UpdateServerOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for UpdateServerOptions
impl Serialize for UpdateServerOptions
Sourceimpl ToSchema for UpdateServerOptions
impl ToSchema for UpdateServerOptions
Sourceimpl Validate for UpdateServerOptions
impl Validate for UpdateServerOptions
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read morefn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
fn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read moreAuto Trait Implementations
impl Freeze for UpdateServerOptions
impl RefUnwindSafe for UpdateServerOptions
impl Send for UpdateServerOptions
impl Sync for UpdateServerOptions
impl Unpin for UpdateServerOptions
impl UnsafeUnpin for UpdateServerOptions
impl UnwindSafe for UpdateServerOptions