pub struct Server {Show 36 fields
pub uuid: Uuid,
pub uuid_short: i32,
pub external_id: Option<CompactString>,
pub allocation: Option<ServerAllocation>,
pub destination_allocation_uuid: Option<Uuid>,
pub node: Fetchable<Node>,
pub destination_node: Option<Fetchable<Node>>,
pub owner: User,
pub egg: Box<NestEgg>,
pub nest: Box<Nest>,
pub backup_configuration: Option<Fetchable<BackupConfiguration>>,
pub status: Option<ServerStatus>,
pub suspended: bool,
pub name: CompactString,
pub description: Option<CompactString>,
pub memory: i64,
pub memory_overhead: i64,
pub swap: i64,
pub disk: i64,
pub io_weight: Option<i16>,
pub cpu: i32,
pub pinned_cpus: Vec<i16>,
pub startup: CompactString,
pub image: CompactString,
pub auto_kill: ServerConfigurationAutoKill,
pub auto_start_behavior: ServerAutoStartBehavior,
pub timezone: Option<CompactString>,
pub hugepages_passthrough_enabled: bool,
pub kvm_passthrough_enabled: bool,
pub allocation_limit: i32,
pub database_limit: i32,
pub backup_limit: i32,
pub schedule_limit: i32,
pub subuser_permissions: Option<Arc<Vec<CompactString>>>,
pub subuser_ignored_files: Option<Vec<CompactString>>,
pub created: NaiveDateTime,
/* private fields */
}Fields
uuid: Uuiduuid_short: i32external_id: Option<CompactString>allocation: Option<ServerAllocation>destination_allocation_uuid: Option<Uuid>node: Fetchable<Node>destination_node: Option<Fetchable<Node>>owner: Useregg: Box<NestEgg>nest: Box<Nest>backup_configuration: Option<Fetchable<BackupConfiguration>>status: Option<ServerStatus>suspended: boolname: CompactStringdescription: Option<CompactString>memory: i64memory_overhead: i64swap: i64disk: i64io_weight: Option<i16>cpu: i32pinned_cpus: Vec<i16>startup: CompactStringimage: CompactStringauto_kill: ServerConfigurationAutoKillauto_start_behavior: ServerAutoStartBehaviortimezone: Option<CompactString>hugepages_passthrough_enabled: boolkvm_passthrough_enabled: boolallocation_limit: i32database_limit: i32backup_limit: i32schedule_limit: i32subuser_permissions: Option<Arc<Vec<CompactString>>>subuser_ignored_files: Option<Vec<CompactString>>created: NaiveDateTimeImplementations
Sourceimpl Server
impl Server
pub async fn by_node_uuid_uuid( database: &Database, node_uuid: Uuid, uuid: Uuid, ) -> Result<Option<Self>, DatabaseError>
pub async fn by_external_id( database: &Database, external_id: &str, ) -> Result<Option<Self>, DatabaseError>
pub async fn by_identifier( database: &Database, identifier: &str, ) -> Result<Option<Self>, DatabaseError>
Sourcepub async fn by_user_identifier(
database: &Database,
user: &User,
identifier: &str,
) -> Result<Option<Self>, Error>
pub async fn by_user_identifier( database: &Database, user: &User, identifier: &str, ) -> Result<Option<Self>, Error>
Get a server by its identifier, ensuring the user has access to it.
Cached for 5 seconds.
pub async fn by_owner_uuid_with_pagination( database: &Database, owner_uuid: Uuid, page: i64, per_page: i64, search: Option<&str>, ) -> Result<Pagination<Self>, DatabaseError>
pub async fn by_user_uuid_server_order_with_pagination( database: &Database, owner_uuid: Uuid, server_order: &[Uuid], page: i64, per_page: i64, search: Option<&str>, ) -> Result<Pagination<Self>, DatabaseError>
pub async fn by_user_uuid_with_pagination( database: &Database, user_uuid: Uuid, page: i64, per_page: i64, search: Option<&str>, ) -> Result<Pagination<Self>, DatabaseError>
pub async fn all_uuids_by_node_uuid_user_uuid( database: &Database, node_uuid: Uuid, user_uuid: Uuid, ) -> Result<Vec<Uuid>, DatabaseError>
pub async fn by_not_user_uuid_with_pagination( database: &Database, user_uuid: Uuid, page: i64, per_page: i64, search: Option<&str>, ) -> Result<Pagination<Self>, DatabaseError>
pub async fn by_node_uuid_with_pagination( database: &Database, node_uuid: Uuid, page: i64, per_page: i64, search: Option<&str>, ) -> Result<Pagination<Self>, DatabaseError>
pub async fn by_node_uuid_transferring_with_pagination( database: &Database, node_uuid: Uuid, page: i64, per_page: i64, search: Option<&str>, ) -> Result<Pagination<Self>, DatabaseError>
pub async fn by_egg_uuid_with_pagination( database: &Database, egg_uuid: Uuid, page: i64, per_page: i64, search: Option<&str>, ) -> Result<Pagination<Self>, DatabaseError>
pub async fn by_backup_configuration_uuid_with_pagination( database: &Database, backup_configuration_uuid: Uuid, page: i64, per_page: i64, search: Option<&str>, ) -> Result<Pagination<Self>, DatabaseError>
pub async fn all_with_pagination( database: &Database, page: i64, per_page: i64, search: Option<&str>, ) -> Result<Pagination<Self>, DatabaseError>
pub async fn count_by_user_uuid( database: &Database, user_uuid: Uuid, ) -> Result<i64, Error>
pub async fn count_by_node_uuid( database: &Database, node_uuid: Uuid, ) -> Result<i64, Error>
pub async fn count_by_egg_uuid( database: &Database, egg_uuid: Uuid, ) -> Result<i64, Error>
Sourcepub async fn fetch_status(
&self,
database: &Database,
) -> Result<Option<ServerStatus>, DatabaseError>
pub async fn fetch_status( &self, database: &Database, ) -> Result<Option<ServerStatus>, DatabaseError>
Fetches the current status of the server from the database. This is the most up-to-date status, as opposed to the potentially cached status in the Server struct.
Sourcepub async fn sync(self, database: &Database) -> Result<(), Error>
pub async fn sync(self, database: &Database) -> Result<(), Error>
Syncs the server with the node. This will update server resources, schedules, name, etc.
Sourcepub async fn batch_sync(self, database: &Arc<Database>)
pub async fn batch_sync(self, database: &Arc<Database>)
Same as sync but runs in a background task, is deduplicated and is not awaited. Any errors will be logged but not returned.
This method is meant to be used in 90% of cases where you want to sync the server with low priority.
Sourcepub async fn install(
&self,
state: &State,
truncate_directory: bool,
installation_script: Option<InstallationScript>,
) -> Result<(), Error>
pub async fn install( &self, state: &State, truncate_directory: bool, installation_script: Option<InstallationScript>, ) -> Result<(), Error>
Triggers a re-installation of the server on the node.
This will only work if the server is in a state that allows re-installation. (None status)
If this is not the case, a DisplayError will be returned.
Sourcepub async fn transfer(
self,
state: &State,
options: ServerTransferOptions,
) -> Result<(), Error>
pub async fn transfer( self, state: &State, options: ServerTransferOptions, ) -> Result<(), Error>
Triggers a transfer of the server to another node.
This will only work if the server is in a state that allows transferring. (None status)
If this is not the case, a DisplayError will be returned.
pub fn wings_permissions( &self, settings: &AppSettings, user: &User, ) -> Vec<&str>
pub fn wings_subuser_permissions<'a>( &self, settings: &AppSettings, subuser: &'a ServerSubuser, ) -> Vec<&'a str>
Sourcepub async fn feature_limits(
&self,
state: &State,
) -> Result<ApiServerFeatureLimits, Error>
pub async fn feature_limits( &self, state: &State, ) -> Result<ApiServerFeatureLimits, Error>
Gets the feature limits for the server, useful in case you need to loop over them or want to pass them to the frontend individually.
pub async fn backup_configuration( &self, database: &Database, ) -> Option<BackupConfiguration>
pub fn is_ignored(&mut self, path: impl AsRef<Path>, is_dir: bool) -> bool
pub async fn into_remote_api_object( self, database: &Database, ) -> Result<RemoteApiServer, Error>